@@ -32,6 +32,7 @@
 #include <libanjuta/interfaces/ianjuta-editor-language.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
 #include <libanjuta/interfaces/ianjuta-editor-assist.h>
+#include <libanjuta/interfaces/ianjuta-editor-tip.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-symbol.h>
 #include <libanjuta/interfaces/ianjuta-language.h>
@@ -41,12 +42,9 @@
 
 /* Pixmaps */
 #define ANJUTA_PIXMAP_SWAP                "anjuta-swap"
-#define ANJUTA_PIXMAP_COMPLETE			  "anjuta-complete"
-#define ANJUTA_PIXMAP_AUTOCOMPLETE        "anjuta-complete-auto"
 #define ANJUTA_PIXMAP_AUTOINDENT          "anjuta-indent-auto"
 #define ANJUTA_STOCK_SWAP                 "anjuta-swap"
 #define ANJUTA_STOCK_COMPLETE         	  "anjuta-complete"
-#define ANJUTA_STOCK_AUTOCOMPLETE         "anjuta-autocomplete"
 #define ANJUTA_STOCK_AUTOINDENT           "anjuta-indent"
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-language-support-cpp-java.xml"
@@ -1063,7 +1061,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 			/* If we encounter a block-start before anything else, the
 			 * statement could hardly be incomplte.
 			 */
-			if (point_ch == '}' && *incomplete_statement == -1)
+			if (point_ch == '{' && *incomplete_statement == -1)
 				*incomplete_statement = 0;
 			
 			break;
@@ -1594,7 +1592,7 @@ install_support (CppJavaPlugin *lang_plugin)
 		ianjuta_language_get_name_from_editor (lang_manager, 
 											   IANJUTA_EDITOR_LANGUAGE (lang_plugin->current_editor), NULL);
 	
-	DEBUG_PRINT("Language support intalled for: %s",
+	DEBUG_PRINT("Language support installed for: %s",
 				lang_plugin->current_language);
 	
 	if (lang_plugin->current_language &&
@@ -1622,32 +1620,18 @@ install_support (CppJavaPlugin *lang_plugin)
 	
 	initialize_indentation_params (lang_plugin);
 	
-	if (IANJUTA_IS_EDITOR_ASSIST (lang_plugin->current_editor) &&
-		!g_str_equal (lang_plugin->current_language, "Vala"))
+	if (!g_str_equal (lang_plugin->current_language, "Vala"))
 	{
-		AnjutaPlugin *plugin;
-		AnjutaUI *ui;
-		GtkAction *action;
-		IAnjutaEditorAssist* iassist;
-		
-		plugin = ANJUTA_PLUGIN (lang_plugin);
-		ui = anjuta_shell_get_ui (plugin->shell, NULL);
-		iassist = IANJUTA_EDITOR_ASSIST (lang_plugin->current_editor);
-		
+		CppJavaAssist *assist;
+
 		g_assert (lang_plugin->assist == NULL);
-		
-		lang_plugin->assist =
-			cpp_java_assist_new (iassist,
-				anjuta_shell_get_interface (plugin->shell,
-											IAnjutaSymbolManager,
-											NULL),
-								 lang_plugin->prefs);
-		
-		/* Enable autocompletion action */
-		action = gtk_action_group_get_action (lang_plugin->action_group, 
-									   "ActionEditAutocomplete");
-		g_object_set (G_OBJECT (action), "visible", TRUE,
-					  "sensitive", TRUE, NULL);
+
+		assist = cpp_java_assist_new (IANJUTA_EDITOR (lang_plugin->current_editor),
+					anjuta_shell_get_interface (ANJUTA_PLUGIN (lang_plugin)->shell,
+												IAnjutaSymbolManager,
+												NULL),
+					lang_plugin->prefs);
+		lang_plugin->assist = assist;
 	}	
 		
 	lang_plugin->support_installed = TRUE;
@@ -1677,21 +1661,9 @@ uninstall_support (CppJavaPlugin *lang_plugin)
 	}
 	
 	if (lang_plugin->assist)
-	{
-		AnjutaPlugin *plugin;
-		AnjutaUI *ui;
-		GtkAction *action;
-		
+	{	
 		g_object_unref (lang_plugin->assist);
 		lang_plugin->assist = NULL;
-		
-		/* Disable autocompletion action */
-		plugin = ANJUTA_PLUGIN (lang_plugin);
-		ui = anjuta_shell_get_ui (plugin->shell, NULL);
-		action = gtk_action_group_get_action (lang_plugin->action_group,
-									   "ActionEditAutocomplete");
-		g_object_set (G_OBJECT (action), "visible", FALSE,
-					  "sensitive", FALSE, NULL);
 	}
 	
 	lang_plugin->support_installed = FALSE;
@@ -1900,39 +1872,23 @@ on_auto_indent (GtkAction *action, gpointer data)
 	ianjuta_document_end_undo_action (IANJUTA_DOCUMENT(editor), NULL);
 }
 
-static void
-on_auto_complete (GtkAction *action, gpointer data)
-{
-	CppJavaPlugin *lang_plugin;
-	lang_plugin = ANJUTA_PLUGIN_CPP_JAVA (data);
-	if (lang_plugin->assist)
-		cpp_java_assist_check (lang_plugin->assist, TRUE, TRUE, FALSE);
-}
-
 static GtkActionEntry actions[] = {
 	{
 		"ActionMenuEdit",
 		NULL, N_("_Edit"),
 		NULL, NULL, NULL
 	},
-	{
-		"ActionEditAutocomplete",
-		ANJUTA_STOCK_AUTOCOMPLETE,
-		N_("_AutoComplete"), "<control>Return",
-		N_("AutoComplete the current word"),
-		G_CALLBACK (on_auto_complete)
-	},
 	{
 		"ActionEditAutoindent",
 		ANJUTA_STOCK_AUTOINDENT,
-		N_("Auto Indent"), "<control>i",
-		N_("Auto indent current line or selection based on indentation settings"),
+		N_("Auto-Indent"), "<control>i",
+		N_("Auto-indent current line or selection based on indentation settings"),
 		G_CALLBACK (on_auto_indent)
 	},
 	{   "ActionFileSwap", 
 		ANJUTA_STOCK_SWAP, 
 		N_("Swap .h/.c"), NULL,
-		N_("Swap c header and source files"),
+		N_("Swap C header and source files"),
 		G_CALLBACK (on_swap_activate)
 	}
 };
@@ -1949,8 +1905,6 @@ register_stock_icons (AnjutaPlugin *plugin)
 	/* Register stock icons */
 	BEGIN_REGISTER_ICON (plugin);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_SWAP, ANJUTA_STOCK_SWAP);
-	REGISTER_ICON_FULL (ANJUTA_PIXMAP_COMPLETE, ANJUTA_STOCK_COMPLETE);	
-	REGISTER_ICON_FULL (ANJUTA_PIXMAP_AUTOCOMPLETE, ANJUTA_STOCK_AUTOCOMPLETE);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_AUTOINDENT, ANJUTA_STOCK_AUTOINDENT);
 	END_REGISTER_ICON;
 }
