@@ -200,13 +200,17 @@ goto_file_tag (SymbolDBPlugin *sdb_plugin, const gchar *word,
 		{
 			engine = sdb_plugin->sdbe_globals;
 		}		
-						
-		iterator = symbol_db_engine_find_symbol_by_name_pattern (engine, 
-															 word,
-															 TRUE,
-															 SYMINFO_SIMPLE |
-															 SYMINFO_KIND |
-															 SYMINFO_FILE_PATH);
+
+		iterator = NULL;
+		if (symbol_db_engine_is_connected (engine)) 
+		{		
+			iterator = symbol_db_engine_find_symbol_by_name_pattern (engine, 
+																 word,
+																 TRUE,
+																 SYMINFO_SIMPLE |
+																 SYMINFO_KIND |
+																 SYMINFO_FILE_PATH);
+		}
 	
 		if (iterator != NULL && symbol_db_engine_iterator_get_n_items (iterator) > 0)
 		{
@@ -306,28 +310,29 @@ on_find_symbol (GtkAction *action, SymbolDBPlugin *sdb_plugin)
 
 static GtkActionEntry actions[] = 
 {
-	{ "ActionMenuGoto", NULL, N_("_Goto"), NULL, NULL, NULL},
+	{ "ActionMenuGoto", NULL, N_("_Go to"), NULL, NULL, NULL},
 	{
 		"ActionSymbolDBGotoDecl",
 		ANJUTA_STOCK_GOTO_DECLARATION,
 		N_("Tag De_claration"),
 		"<shift><control>d",
-		N_("Goto symbol declaration"),
+		N_("Go to symbol declaration"),
 		G_CALLBACK (on_goto_file_tag_decl_activate)
 	},
 	{
 		"ActionSymbolDBGotoImpl",
 		ANJUTA_STOCK_GOTO_IMPLEMENTATION,
+		/* Translators: Go to the line where the tag is implemented */
 		N_("Tag _Implementation"),
 		"<control>d",
-		N_("Goto symbol definition"),
+		N_("Go to symbol definition"),
 		G_CALLBACK (on_goto_file_tag_impl_activate)
 	}	
 };
 
 static GtkActionEntry actions_search[] = {
   { 
-	"ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol..."),
+	"ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol…"),
 	"<control>l", N_("Find Symbol"),
     G_CALLBACK (on_find_symbol)
   }
@@ -540,7 +545,7 @@ on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 	DEBUG_PRINT ("%s", "on_editor_destroy ()");
 	if (!sdb_plugin->editor_connected || !sdb_plugin->dbv_view_tree)
 	{
-		DEBUG_PRINT ("%s", "on_editor_destroy (): returning....");
+		DEBUG_PRINT ("%s", "on_editor_destroy (): returning….");
 		return;
 	}
 	
@@ -550,7 +555,7 @@ on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 	/* was it the last file loaded? */
 	if (g_hash_table_size (sdb_plugin->editor_connected) <= 0)
 	{
-		DEBUG_PRINT ("%s", "displaying nothing...");
+		DEBUG_PRINT ("%s", "displaying nothing…");
 		symbol_db_view_locals_display_nothing (
 				SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals), TRUE);
 	}
@@ -614,8 +619,13 @@ on_editor_saved (IAnjutaEditor *editor, GFile* file,
 		old_uri = NULL;
 
 	/* files_array will be freed once updating has taken place */
-	proc_id = symbol_db_engine_update_files_symbols (sdb_plugin->sdbe_project, 
-						sdb_plugin->project_root_dir, files_array, TRUE);
+	proc_id = 0;
+	if (symbol_db_engine_is_connected (sdb_plugin->sdbe_project))
+	{
+		proc_id = symbol_db_engine_update_files_symbols (sdb_plugin->sdbe_project, 
+							sdb_plugin->project_root_dir, files_array, TRUE);
+	}
+	
 	if (proc_id > 0)
 	{		
 		/* add a task so that scan_end_manager can manage this */
@@ -692,8 +702,8 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	{
 		sdb_plugin->buffer_update_semaphore = TRUE;
 	}
-	else
-	{
+	else 
+	{		
 		symbol_db_view_locals_update_list (
 					SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals),
 					 sdb_plugin->sdbe_project, local_path, FALSE);
@@ -1166,7 +1176,7 @@ on_system_single_file_scan_end (SymbolDBEngine *dbe, gpointer data)
 	sdb_plugin->files_count_system_done++;	
 	if (sdb_plugin->files_count_system_done >= sdb_plugin->files_count_system)
 	{
-		message = g_strdup_printf (_("%s: Generating inheritances..."), 
+		message = g_strdup_printf (_("%s: Generating inheritances…"), 
 								   sdb_plugin->current_scanned_package);
 	}
 	else
@@ -1202,7 +1212,7 @@ on_project_single_file_scan_end (SymbolDBEngine *dbe, gpointer data)
 	
 	sdb_plugin->files_count_project_done++;	
 	if (sdb_plugin->files_count_project_done >= sdb_plugin->files_count_project)
-		message = g_strdup_printf (_("Generating inheritances..."));
+		message = g_strdup_printf (_("Generating inheritances…"));
 	else
 		message = g_strdup_printf (_("%d files scanned out of %d"), 
 							   sdb_plugin->files_count_project_done, sdb_plugin->files_count_project);
@@ -1240,9 +1250,9 @@ clear_project_progress_bar (SymbolDBEngine *dbe, gpointer data)
 						 sdb_plugin->sdbe_project);
 	
 	/* ok, enable local symbols view */
-	if (!IANJUTA_IS_EDITOR (sdb_plugin->current_editor))
+	if (sdb_plugin->current_editor == NULL  ||
+	    IANJUTA_IS_FILE (sdb_plugin->current_editor) == FALSE)
 	{
-		DEBUG_PRINT ("!IANJUTA_IS_EDITOR (sdb_plugin->current_editor))");
 		return;
 	}
 	
@@ -1412,7 +1422,7 @@ do_import_project_sources (AnjutaPlugin *plugin, IAnjutaProjectManager *pm,
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);	
 
 	prj_elements_list = ianjuta_project_manager_get_elements (pm,
-					   IANJUTA_PROJECT_MANAGER_SOURCE,
+					   ANJUTA_PROJECT_SOURCE,
 					   NULL);
 	
 	if (prj_elements_list == NULL)
@@ -1427,7 +1437,7 @@ do_import_project_sources (AnjutaPlugin *plugin, IAnjutaProjectManager *pm,
 	sdb_plugin->is_project_importing = TRUE;
 	enable_view_signals (sdb_plugin, FALSE, TRUE);
 	
-	DEBUG_PRINT ("Retrieving %d gbf sources of the project...",
+	DEBUG_PRINT ("Retrieving %d gbf sources of the project…",
 					 g_list_length (prj_elements_list));
 
 	/* create the storage array. The file names will be strdup'd and put here. 
@@ -1572,13 +1582,13 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 	GHashTable *prj_elements_hash;
 	GPtrArray *to_add_files = NULL;
 	gint i;
-	gint real_added ;
+	gint real_added = 0;
 	
 	pm = anjuta_shell_get_interface (ANJUTA_PLUGIN (sdb_plugin)->shell,
 									 IAnjutaProjectManager, NULL);	
 
 	prj_elements_list = ianjuta_project_manager_get_elements (pm,
-		   IANJUTA_PROJECT_MANAGER_SOURCE,
+		   ANJUTA_PROJECT_SOURCE,
 		   NULL);
 	
 	/* fill an hash table with all the items of the list just taken. 
@@ -1829,9 +1839,12 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		gchar *anjuta_cache_path;
 		/* open the connection to global db */
 		anjuta_cache_path = anjuta_util_get_user_cache_file_path (".", NULL);
-		symbol_db_engine_open_db (sdb_plugin->sdbe_globals, 
+		if (symbol_db_engine_open_db (sdb_plugin->sdbe_globals, 
 							  anjuta_cache_path, 
-							  PROJECT_GLOBALS);
+							  PROJECT_GLOBALS) == DB_OPEN_STATUS_FATAL)
+		{
+			g_error ("Opening global project under %s", anjuta_cache_path);
+		}
 		g_free (anjuta_cache_path);
 	
 		/* unref and recreate the sdbs object */
@@ -1885,27 +1898,32 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		lang_hash = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, 
 										  sources_array_free);
 
-		/* is it a fresh-new project? is it an imported project with 
-		 * no 'new' symbol-db database but the 'old' one symbol-browser? 
-		 */
-		if (symbol_db_engine_db_exists (sdb_plugin->sdbe_project, 
-										root_dir) == FALSE)
-		{
-			DEBUG_PRINT ("Project %s does not exist", root_dir);
-			needs_sources_scan = TRUE;
-			project_exist = FALSE;
-		}
-		else 
-		{
-			project_exist = TRUE;
-		}
-
 		/* we'll use the same values for db_directory and project_directory */
 		DEBUG_PRINT ("Opening db %s and project_dir %s", root_dir, root_dir);
-		if (symbol_db_engine_open_db (sdb_plugin->sdbe_project, root_dir, 
-										  root_dir) == FALSE)
+		gint open_status = symbol_db_engine_open_db (sdb_plugin->sdbe_project, root_dir, 
+										  root_dir);
+
+		/* is it a fresh-new project? is it an imported project with 
+		 * no 'new' symbol-db database but the 'old' one symbol-browser? 
+		 */		
+		switch (open_status)
 		{
-			g_error ("*** Error in opening db ***");
+			case DB_OPEN_STATUS_FATAL:
+				g_error ("*** Error in opening db ***");
+				return;
+				
+			case DB_OPEN_STATUS_NORMAL:
+				project_exist = TRUE;
+				break;
+
+			case DB_OPEN_STATUS_CREATE:
+			case DB_OPEN_STATUS_UPGRADE:
+				needs_sources_scan = TRUE;
+				project_exist = FALSE;
+				break;
+				
+			default:
+				break;
 		}
 			
 		/* if project did not exist add a new project */
@@ -1964,7 +1982,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 			}				
 		}
 		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (sdb_plugin->progress_bar_project),
-								   _("Populating symbols' db..."));
+								   _("Populating symbol database…"));
 		id = g_idle_add ((GSourceFunc) gtk_progress_bar_pulse, 
 						 sdb_plugin->progress_bar_project);
 		gtk_widget_show (sdb_plugin->progress_bar_project);
@@ -2197,7 +2215,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	gchar *ctags_path;
 	GtkWidget *label;
 	
-	DEBUG_PRINT ("SymbolDBPlugin: Activating SymbolDBPlugin plugin ...");
+	DEBUG_PRINT ("SymbolDBPlugin: Activating SymbolDBPlugin plugin …");
 	
 	/* Initialize gda library. */
 	gda_init ();
@@ -2266,9 +2284,13 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	
 	/* open it */
 	anjuta_cache_path = anjuta_util_get_user_cache_file_path (".", NULL);
-	symbol_db_engine_open_db (sdb_plugin->sdbe_globals, 
+	if (symbol_db_engine_open_db (sdb_plugin->sdbe_globals, 
 							  anjuta_cache_path, 
-							  PROJECT_GLOBALS);
+							  PROJECT_GLOBALS) == DB_OPEN_STATUS_FATAL)
+	{
+		g_error ("Opening global project under %s", anjuta_cache_path);
+	}
+	
 	g_free (anjuta_cache_path);
 	
 	/* create the object that'll manage the globals population */
@@ -2293,8 +2315,34 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	
 	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "scan-end",
 		  		G_CALLBACK (on_scan_end_manager), sdb_plugin);
+
+	/* connect signals for interface to receive them */
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "symbol-inserted",
+				G_CALLBACK (on_isymbol_manager_sys_symbol_inserted), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "symbol-updated",
+				G_CALLBACK (on_isymbol_manager_sys_symbol_updated), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "symbol-removed",
+				G_CALLBACK (on_isymbol_manager_sys_symbol_removed), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "scan-end",
+				G_CALLBACK (on_isymbol_manager_sys_scan_end), sdb_plugin);
 	
-	/* sets preferences to NULL, it'll be instantiated when required.\ */
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "symbol-inserted",
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "symbol-updated",
+				G_CALLBACK (on_isymbol_manager_prj_symbol_updated), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "symbol-removed",
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), sdb_plugin);
+	
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "scan-end",
+				G_CALLBACK (on_isymbol_manager_prj_scan_end), sdb_plugin);
+
+	
+	/* sets preferences to NULL, it'll be instantiated when required. */
 	sdb_plugin->sdbp = NULL;
 	
 	/* Create widgets */
@@ -2340,15 +2388,15 @@ symbol_db_activate (AnjutaPlugin *plugin)
 
 	gtk_widget_show_all (sdb_plugin->dbv_hbox);
 	
-	sdb_plugin->progress_bar_project = gtk_progress_bar_new();
+	sdb_plugin->progress_bar_project = gtk_progress_bar_new();	
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_project),
-									PANGO_ELLIPSIZE_MIDDLE);
+									PANGO_ELLIPSIZE_MIDDLE);	
 	g_object_ref (sdb_plugin->progress_bar_project);
 	
 	sdb_plugin->progress_bar_system = gtk_progress_bar_new();
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_system),
 									PANGO_ELLIPSIZE_MIDDLE);
-	g_object_ref (sdb_plugin->progress_bar_system);
+	g_object_ref (sdb_plugin->progress_bar_system);	
 	
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->dbv_notebook,
 						TRUE, TRUE, 0);
@@ -2357,7 +2405,6 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->progress_bar_system,
 						FALSE, FALSE, 0);	
 	gtk_widget_show_all (sdb_plugin->dbv_main);
-	
 
 	/* Local symbols */
 	sdb_plugin->scrolled_locals = gtk_scrolled_window_new (NULL, NULL);
@@ -2440,7 +2487,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 							  sdb_plugin->dbv_view_search_tab_label);
 
 	gtk_widget_show_all (sdb_plugin->dbv_notebook);
-	
+
 	/* setting focus to the tree_view*/
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (sdb_plugin->dbv_notebook), 0);
 
@@ -2488,7 +2535,11 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	
 	g_signal_connect (plugin->shell, "save-session", 
 					  G_CALLBACK (on_session_save), plugin);
-		
+
+	/* be sure to hide the progress bars in case no project has been opened. */
+	gtk_widget_hide (sdb_plugin->progress_bar_project);
+	gtk_widget_hide (sdb_plugin->progress_bar_system);	
+	
 	return TRUE;
 }
 
@@ -2499,7 +2550,7 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 
-	DEBUG_PRINT ("%s", "SymbolDBPlugin: Dectivating SymbolDBPlugin plugin ...");
+	DEBUG_PRINT ("%s", "SymbolDBPlugin: Dectivating SymbolDBPlugin plugin …");
 	
 	/* disconnect some signals */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->dbv_view_tree_locals),
@@ -2549,6 +2600,33 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbs),
 										  on_scan_end_manager,
 										  plugin);
+
+	/* disconnect the interface ones */
+	/* connect signals for interface to receive them */
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_symbol_inserted), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_symbol_updated), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_symbol_removed), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_scan_end), plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project),
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project), 
+				G_CALLBACK (on_isymbol_manager_prj_symbol_updated), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project),
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project),
+				G_CALLBACK (on_isymbol_manager_prj_scan_end), plugin);
+	
 	if (sdb_plugin->update_timer)
 	{
 		g_timer_destroy (sdb_plugin->update_timer);
